# Changelog

## [0.2.0](https://github.com/SarthakJariwala/sqlsaber/compare/sqlsaber-sandbox-v0.1.1...sqlsaber-sandbox-v0.2.0) (2026-02-06)


### Features

* visualization model override support via api and prompt improvements ([35a506b](https://github.com/SarthakJariwala/sqlsaber/commit/35a506b23337dd64f8f20606e7e547755eae6f21))

## [0.1.1](https://github.com/SarthakJariwala/sqlsaber/compare/sqlsaber-sandbox-v0.1.0...sqlsaber-sandbox-v0.1.1) (2026-02-05)


### Features

* first plugins release ([bd1a5b5](https://github.com/SarthakJariwala/sqlsaber/commit/bd1a5b5079d6eaff2a52bdf4b8812d54ea8c2783))
